@@ -722,7 +722,7 @@ def exits_transforms(exits, ramps, access_path, lanes_path):
     return exits
 
 
-def occupancy_transforms(occupancy, ramps):
+def occupancy_transforms(occupancy):
     # DATE
     occupancy['Date'] = datetime.strftime(datetime.now(), '%Y-%m-%d %H:00:00')
 
@@ -740,28 +740,43 @@ def occupancy_transforms(occupancy, ramps):
         last_start = this_start - timedelta(days=364)
         last_end = this_end - timedelta(days=364)
 
-    # Initially Set Year Filter Column to Number of Years Ago
-    occupancy['Year'] = this_start.year - occupancy['Exit Time'].dt.year
+    # Format Occupancy Data Date
+    occupancy['Date'] = pd.to_datetime(occupancy['Date'])
 
+    # Initially Set Year Filter Column to Number of Years Ago
+    occupancy['Year'] = this_start.year - occupancy['Date'].dt.year
+
+    # YEAR FILTERS AND COMPARISON DATES
     # Determine Number of Unique Years in Dataset
     years_ago = occupancy['Year'].unique()
 
-    # COMPARISON DATE
-    occupancy['Comparison Date'] = occupancy['Exit Time Hour']
+    # Set Comparison Dates
+    occupancy['Comparison Date'] = occupancy['Date']
 
     for number in years_ago:
         if number > 0:
             # Check is Current Year is Leap Year and Set Dates Accordingly
             if datetime.now().year - 1 % 4 == 0:
-                occupancy.loc[occupancy['Year'] == number, 'Comparison Date'] = occupancy['Exit Time Hour'] + timedelta(
+                occupancy.loc[occupancy['Year'] == number, 'Comparison Date'] = occupancy[
+                                                                                            'Date'] + timedelta(
                     days=364 - int(number))
             else:
-                occupancy.loc[occupancy['Year'] == number, 'Comparison Date'] = occupancy['Exit Time Hour'] + timedelta(
+                occupancy.loc[occupancy['Year'] == number, 'Comparison Date'] = occupancy[
+                                                                                            'Date'] + timedelta(
                     days=365 - int(number))
 
-    # YEAR
-    occupancy.loc[this_start.year - occupancy['Exit Time'].dt.year == 0, 'Year'] = 'This Year'
-    occupancy.loc[this_start.year - occupancy['Exit Time'].dt.year == 1, 'Year'] = 'Last Year'
-    occupancy.loc[this_start.year - occupancy['Exit Time'].dt.year > 1, 'Year'] = str(
-        this_start.year - occupancy['Exit Time'].dt.year) + ' Years Ago'
+    occupancy['Comparison Date'] = pd.to_datetime(occupancy['Comparison Date'], '%Y-%m-%d %H:%M:%S')
 
+    # Convert Year Column to Filter by This, Last, and Previous Years
+    occupancy.loc[this_start.year - occupancy['Date'].dt.year == 0, 'Year'] = 'This Year'
+    occupancy.loc[this_start.year - occupancy['Date'].dt.year == 1, 'Year'] = 'Last Year'
+    occupancy.loc[this_start.year - occupancy['Date'].dt.year > 1, 'Year'] = str(
+        this_start.year - occupancy['Date'].dt.year) + ' Years Ago'
+
+    occupancy.loc[
+        occupancy['Date'] < datetime.strftime(this_start, '%Y-%m-%d %H:%M:%S'), 'Year'] = 'Last Year'
+    occupancy.loc[
+        occupancy['Date'] < datetime.strftime(last_start, '%Y-%m-%d %H:%M:%S'), 'Year'] = str(
+        occupancy['Year']) + ' Years Ago'
+
+    return occupancy
